@@ -1,4 +1,4 @@
-/* ANSI-C code produced by gperf version 3.1 */
+/* C code produced by gperf version 3.0.4 */
 /* Command-line: gperf -a -c -C -o -t -p -T -k '1,2,$' -N lookup_element dtd.hash  */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -25,7 +25,7 @@
       && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
       && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
 /* The character set is not based on ISO-646.  */
-#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
+error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
 #endif
 
 #line 1 "dtd.hash"
@@ -74,15 +74,15 @@ EXPORT typedef struct _ElementType {
 } ElementType;
 
 /* lookup_element -- look up the string in the hash table */
-EXPORT const ElementType * lookup_element(register const char *str,
-					  register size_t len);
+EXPORT const ElementType * lookup_element(/* register const char *str,
+					  register unsigned int len */);
 
 /* Different kinds of parent elements: */
 #define PHRASE "abbr", "acronym", "b", "bdi", "bdo", "big", "cite", "code", "dfn", "em", "i", "kbd", "q", "s", "samp", "small", "span", "strong", "sub", "sup", "time", "tt", "u", "var"
 #define BRIDGE "p", "address", "caption", "dt", "h1", "h2", "h3", "h4", "h5", "h6", "legend", "pre"
 #define FLOW "article", "aside", "dd", "del", "details", "div", "fieldset", "figcaption", "figure", "footer", "header", "ins", "li", "nav", "section", "main", "object", "td", "th"
 #define INLINE_PARENT BRIDGE, PHRASE, FLOW
-#define BLOCK_PARENT "body", "blockquote", "map", "noscript"
+#define BLOCK_PARENT "body", "blockquote", "map", "main"
 
 #define TOTAL_KEYWORDS 97
 #define MIN_WORD_LENGTH 1
@@ -99,7 +99,9 @@ inline
 #endif
 #endif
 static unsigned int
-hash (register const char *str, register size_t len)
+hash (str, len)
+     register const char *str;
+     register unsigned int len;
 {
   static const unsigned char asso_values[] =
     {
@@ -130,7 +132,7 @@ hash (register const char *str, register size_t len)
       228, 228, 228, 228, 228, 228, 228, 228, 228, 228,
       228, 228, 228, 228, 228, 228
     };
-  register unsigned int hval = len;
+  register int hval = len;
 
   switch (hval)
     {
@@ -144,22 +146,30 @@ hash (register const char *str, register size_t len)
   return hval + asso_values[(unsigned char)str[len - 1]];
 }
 
+#ifdef __GNUC__
+__inline
+#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
+__attribute__ ((__gnu_inline__))
+#endif
+#endif
 const ElementType *
-lookup_element (register const char *str, register size_t len)
+lookup_element (str, len)
+     register const char *str;
+     register unsigned int len;
 {
   static const ElementType wordlist[] =
     {
       {""},
 #line 130 "dtd.hash"
-      {"q",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"q",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 153 "dtd.hash"
-      {"tt",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"tt",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""}, {""}, {""},
 #line 90 "dtd.hash"
       {"dt",		1, 0, 0, 1, 0, 0, 1, 1, {"dl", NULL}},
       {""}, {""},
 #line 143 "dtd.hash"
-      {"table",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"table",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 62 "dtd.hash"
       {"a",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "label", NULL}},
 #line 145 "dtd.hash"
@@ -173,21 +183,21 @@ lookup_element (register const char *str, register size_t len)
 #line 84 "dtd.hash"
       {"dd",		1, 0, 0, 1, 0, 0, 1, 1, {"dl", NULL}},
 #line 85 "dtd.hash"
-      {"del",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, BLOCK_PARENT, "a", "button", "colgroup", "dl", "form", "label", "ol", "optgroup", "option", "select", "table", "tbody", "textarea", "tfoot", "thead", "ul", NULL}},
+      {"del",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, BLOCK_PARENT, "a", "button", "noscript", "form", "label", "option", "textarea", NULL}},
 #line 120 "dtd.hash"
-      {"meta",		0, 1, 0, 1, 0, 0, 1, 0, {INLINE_PARENT, "head", "a", "button", "label", NULL}},
+      {"meta",		0, 1, 0, 1, 0, 0, 1, 0, {INLINE_PARENT, "head", "a", "button", "noscript", "label", NULL}},
 #line 92 "dtd.hash"
-      {"embed",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"embed",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 115 "dtd.hash"
       {"legend",		1, 0, 0, 1, 1, 0, 1, 1, {"fieldset", NULL}},
 #line 91 "dtd.hash"
-      {"em",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"em",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""},
 #line 150 "dtd.hash"
       {"title",		1, 0, 0, 1, 1, 0, 1, 1, {"head", NULL}},
       {""},
 #line 89 "dtd.hash"
-      {"dl",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"dl",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""}, {""},
 #line 114 "dtd.hash"
       {"label",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", NULL}},
@@ -198,152 +208,152 @@ lookup_element (register const char *str, register size_t len)
       {"select",		0, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "label", NULL}},
       {""}, {""}, {""},
 #line 68 "dtd.hash"
-      {"aside",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"aside",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 108 "dtd.hash"
-      {"i",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"i",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 86 "dtd.hash"
-      {"details",	1, 0, 0, 1, 1, 0, 1, 1, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"details",	1, 0, 0, 1, 1, 0, 1, 1, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 119 "dtd.hash"
-      {"map",		0, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"map",		0, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 118 "dtd.hash"
       {"main",		1, 0, 0, 1, 1, 0, 1, 1, {"body", "div", "noscript", NULL}},
 #line 128 "dtd.hash"
       {"param",		0, 1, 0, 1, 0, 0, 1, 1, {"object", NULL}},
 #line 113 "dtd.hash"
-      {"keygen",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"keygen",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 65 "dtd.hash"
-      {"address",	1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"address",	1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""},
 #line 117 "dtd.hash"
       {"link",		0, 1, 0, 1, 0, 0, 1, 0, {"head", NULL}},
 #line 110 "dtd.hash"
       {"input",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "label", NULL}},
 #line 127 "dtd.hash"
-      {"p",		1, 0, 0, 1, 0, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"p",		1, 0, 0, 1, 0, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 116 "dtd.hash"
       {"li",		1, 0, 0, 1, 0, 0, 1, 1, {"ul", "ol", NULL}},
       {""}, {""},
 #line 135 "dtd.hash"
-      {"small",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"small",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""},
 #line 124 "dtd.hash"
-      {"ol",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"ol",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""}, {""}, {""}, {""},
 #line 133 "dtd.hash"
-      {"section",	1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"section",	1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""},
 #line 131 "dtd.hash"
-      {"samp",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"samp",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""},
 #line 103 "dtd.hash"
-      {"h6",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"h6",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 122 "dtd.hash"
-      {"noscript",	0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"noscript",	1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, BLOCK_PARENT, "a", "button", "noscript", "form", "label", "option", "textarea",  NULL}},
 #line 71 "dtd.hash"
       {"base",		0, 1, 0, 1, 0, 0, 1, 1, {"head", NULL}},
 #line 109 "dtd.hash"
-      {"img",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"img",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 136 "dtd.hash"
       {"source",		0, 1, 0, 1, 0, 0, 1, 1, {"audio", "video", "template", NULL}},
       {""},
 #line 138 "dtd.hash"
-      {"strong",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"strong",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 104 "dtd.hash"
       {"head",		0, 0, 0, 0, 0, 0, 1, 1, {"html", NULL}},
 #line 149 "dtd.hash"
       {"thead",		0, 0, 0, 1, 0, 0, 1, 1, {"table", NULL}},
       {""},
 #line 102 "dtd.hash"
-      {"h5",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"h5",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 111 "dtd.hash"
-      {"ins",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, BLOCK_PARENT, "a", "button", "colgroup", "dl", "form", "label", "ol", "optgroup", "option", "select", "table", "tbody", "textarea", "tfoot", "thead", "ul", NULL}},
+      {"ins",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, BLOCK_PARENT, "a", "button", "noscript", "form", "label", "option", "textarea",  NULL}},
 #line 107 "dtd.hash"
       {"html",		0, 0, 0, 0, 0, 0, 1, 1, {NULL, NULL}},
 #line 75 "dtd.hash"
-      {"blockquote",	0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"blockquote",	0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""}, {""},
 #line 112 "dtd.hash"
-      {"kbd",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"kbd",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 137 "dtd.hash"
-      {"span",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"span",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""},
 #line 154 "dtd.hash"
-      {"ul",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"ul",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 72 "dtd.hash"
-      {"bdi",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"bdi",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""},
 #line 147 "dtd.hash"
       {"tfoot",		0, 0, 0, 1, 0, 0, 1, 1, {"table", NULL}},
 #line 126 "dtd.hash"
       {"option",		1, 0, 0, 1, 0, 0, 1, 1, {"select", "optgroup", NULL}},
 #line 67 "dtd.hash"
-      {"article",	1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"article",	1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 125 "dtd.hash"
       {"optgroup",	0, 0, 0, 1, 1, 0, 1, 1, {"select", NULL}},
 #line 66 "dtd.hash"
       {"area",		0, 1, 0, 1, 0, 0, 0, 0, {"map", NULL}},
       {""}, {""},
 #line 101 "dtd.hash"
-      {"h4",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"h4",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""}, {""},
 #line 152 "dtd.hash"
       {"track",		0, 1, 0, 1, 0, 0, 1, 1, {"audio", "video", "template", NULL}},
 #line 123 "dtd.hash"
-      {"object",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "del", "header", "aside", "section", "main", "article", "nav", "fieldset", "head", "ins", "label", "object", NULL}},
+      {"object",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "del", "header", "aside", "section", "main", "article", "nav", "fieldset", "head", "ins", "label", "object", NULL}},
 #line 64 "dtd.hash"
-      {"acronym",	1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"acronym",	1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 73 "dtd.hash"
-      {"bdo",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"bdo",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 80 "dtd.hash"
-      {"cite",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"cite",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 144 "dtd.hash"
       {"tbody",		0, 0, 0, 0, 0, 0, 1, 1, {"table", NULL}},
       {""},
 #line 100 "dtd.hash"
-      {"h3",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"h3",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 129 "dtd.hash"
-      {"pre",		1, 0, 0, 1, 1, 1, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"pre",		1, 0, 0, 1, 1, 1, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""},
 #line 69 "dtd.hash"
-      {"audio",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"audio",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 95 "dtd.hash"
-      {"figure",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"figure",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""},
 #line 93 "dtd.hash"
       {"fieldset",	1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "form", NULL}},
       {""}, {""},
 #line 132 "dtd.hash"
-      {"script",		1, 0, 1, 1, 1, 1, 1, 0, {"body", INLINE_PARENT, "blockquote", "head", "map", "a", "button", "form", "label", NULL}},
+      {"script",		1, 0, 1, 1, 1, 1, 1, 0, {"body", INLINE_PARENT, "blockquote", "head", "map", "a", "button", "noscript", "form", "label", NULL}},
 #line 79 "dtd.hash"
       {"caption",	1, 0, 0, 1, 1, 0, 1, 1, {"table", NULL}},
 #line 87 "dtd.hash"
-      {"dfn",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"dfn",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 81 "dtd.hash"
-      {"code",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"code",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 74 "dtd.hash"
-      {"big",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"big",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 70 "dtd.hash"
-      {"b",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"b",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""},
 #line 142 "dtd.hash"
-      {"sup",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"sup",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""}, {""},
 #line 99 "dtd.hash"
-      {"h2",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"h2",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 82 "dtd.hash"
       {"col",		0, 1, 0, 1, 0, 0, 0, 0, {"colgroup", "table", NULL}},
       {""}, {""}, {""},
 #line 148 "dtd.hash"
       {"th",		1, 0, 0, 1, 0, 0, 1, 1, {"tr", NULL}},
 #line 88 "dtd.hash"
-      {"div",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"div",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 97 "dtd.hash"
       {"form",		0, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, NULL}},
       {""}, {""},
 #line 98 "dtd.hash"
-      {"h1",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"h1",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 121 "dtd.hash"
-      {"nav",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"nav",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 76 "dtd.hash"
       {"body",		0, 0, 0, 0, 0, 0, 1, 1, {"html", NULL}},
 #line 94 "dtd.hash"
@@ -352,50 +362,50 @@ lookup_element (register const char *str, register size_t len)
 #line 141 "dtd.hash"
       {"summary",	1, 0, 0, 1, 1, 0, 0, 0, {"details", NULL}},
 #line 157 "dtd.hash"
-      {"wbr",		0, 1, 0, 1, 0, 0, 0, 1, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"wbr",		0, 1, 0, 1, 0, 0, 0, 1, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""}, {""}, {""},
 #line 83 "dtd.hash"
       {"colgroup",	0, 0, 0, 1, 1, 0, 1, 1, {"table", NULL}},
 #line 63 "dtd.hash"
-      {"abbr",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"abbr",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""},
 #line 105 "dtd.hash"
-      {"header",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"header",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""}, {""}, {""}, {""},
 #line 78 "dtd.hash"
       {"button",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "label", NULL}},
       {""},
 #line 140 "dtd.hash"
-      {"sub",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"sub",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""}, {""},
 #line 151 "dtd.hash"
       {"tr",		0, 0, 0, 1, 0, 0, 1, 1, {"tbody", "tfoot", "thead", NULL}},
       {""}, {""},
 #line 156 "dtd.hash"
-      {"video",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"video",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
 #line 155 "dtd.hash"
-      {"var",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"var",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""},
 #line 96 "dtd.hash"
-      {"footer",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}},
+      {"footer",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""},
 #line 77 "dtd.hash"
-      {"br",		0, 1, 0, 1, 0, 0, 0, 1, {INLINE_PARENT, "a", "button", "label", NULL}},
+      {"br",		0, 1, 0, 1, 0, 0, 0, 1, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""}, {""}, {""},
 #line 106 "dtd.hash"
-      {"hr",		0, 1, 0, 1, 0, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "form", NULL}}
+      {"hr",		0, 1, 0, 1, 0, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}}
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register unsigned int key = hash (str, len);
+      register int key = hash (str, len);
 
-      if (key <= MAX_HASH_VALUE)
+      if (key <= MAX_HASH_VALUE && key >= 0)
         {
           register const char *s = wordlist[key].name;
 
