@@ -22,22 +22,8 @@
 #include <stdio.h>
 #include <errno.h>
 #include <stdlib.h>
-#include "export.h"
 #include "errexit.e"
-
-EXPORT typedef signed long long int off64_t;
-
-EXPORT typedef ssize_t cookie_read_function_t (void *, char *, size_t);
-EXPORT typedef ssize_t cookie_write_function_t (void *, const char *, size_t);
-EXPORT typedef int cookie_seek_function_t (void *, off64_t, int);
-EXPORT typedef int cookie_close_function_t (void *);
-
-EXPORT typedef struct {
-  cookie_read_function_t *read;
-  cookie_write_function_t *write;
-  cookie_seek_function_t *seek;
-  cookie_close_function_t *close;
-} cookie_io_functions_t;
+#include "fopencookie.h"
 
 typedef struct {
   cookie_read_function_t *read;
@@ -80,7 +66,7 @@ static int closefn(void *sc)
 
 
 /* fopencookie -- open a stream defined by four callback functions */
-EXPORT FILE *fopencookie(void *cookie, const char *mode,
+FILE *fopencookie(void *cookie, const char *mode,
 			 cookie_io_functions_t funcs)
 {
   cookiewrapper *s;
