@@ -225,7 +225,7 @@ void handle_endtag(void *clientdata, string name)
 /* usage -- print usage message and exit */
 static void usage(const conststring progname)
 {
-  fprintf(stderr, "Usage: %s [-v] [-i old-URL] [-o new-URL] [URL [URL]]\n", progname);
+  fprintf(stderr, "Usage: %s [-v] [-s] [-i old-URL] [-o new-URL] [URL [URL]]\n", progname);
   exit(1);
 }
 
