@@ -32,7 +32,6 @@
  * a normal one. "index-inst" is an alias for "index", provided for
  * backward compatibility.
  *
- * To do: get rid of MAXSTR.
  * To do: an option to split the index at each new first letter.
  *
  * Copyright © 1994-2005 World Wide Web Consortium
@@ -40,7 +39,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 11 Apr 2000
- * Version: $Id: hxindex.c,v 1.22 2016/03/04 15:05:37 bbos Exp $
+ * Version: $Id: hxindex.c,v 1.24 2018/02/23 19:05:04 bbos Exp $
  *
  **/
 #include "config.h"
@@ -98,7 +97,6 @@ int strerror_r(int errnum, char *buf, size_t n);
 #define INDEX_DEF "index-def"	/* class="index-def" */
 #define TARGET "bctarget"	/* CLASS="...bctarget..." */
 
-#define MAXSTR 2048		/* Max. length of URL + term */
 #define MAXSUBS 20		/* Max. depth of subterms */
 #define SECNO "secno"		/* Class of elements that define section # */
 #define NO_NUM "no-num"		/* Class of elements without a section # */
@@ -106,7 +104,8 @@ int strerror_r(int errnum, char *buf, size_t n);
 typedef struct _indexterm {
   string url;
   int importance;		/* 1 (low) or 2 (high) */
-  string secno;
+  string secno;			/* For option -n */
+  string sectitle;		/* For option -N */
   string doctitle;
   string *terms;		/* Array of subterms */
   wchar_t **sortkeys;		/* Array of normalized subterms */
@@ -123,6 +122,7 @@ static Indexterm globalprevious; /* Must be global for twalk */
 static string globalurlprevious;/* Must be global for twalk */
 static bool bctarget = true;	/* Add <A name=> after IDs */
 static bool use_secno = false;	/* Anchor text is "#" instead of section # */
+static bool use_sectitle = false; /* Anchor text is section title, not # */
 static bool final = false;	/* Leave used attributes in document */
 static bool trim_punct = true;	/* Remove trailing punctuation from terms */
 static string section_name = NULL; /* Term meaning "section %s" */
@@ -391,41 +391,6 @@ static void print_title(const Indexterm term)
   putchar('"');
 }
 
-#if 0
-/* print_full_term -- print the full term for use in a TITLE attribute */
-static void print_full_term(const Indexterm term)
-{
-  enum {TEXT, TAG, DQUOTE, SQUOTE} state;
-  string h;
-  int i;
-
-  for (state = TEXT, i = 0; i < term->nrkeys; i++) {
-    if (i != 0) fputs(", ", stdout);
-    for (h = term->terms[i]; *h; h++)
-      switch (state) {
-      case TEXT:
-	if (*h == '<') state = TAG;
-	else if (*h == '"') fputs("&quot;", stdout);
-	else putchar(*h);
-	break;
-      case TAG:
-	if (*h == '>') state = TEXT;
-	else if (*h == '"') state = DQUOTE;
-	else if (*h == '\'') state = SQUOTE;
-	break;
-      case DQUOTE:
-	if (*h == '"') state = TAG;
-	break;
-      case SQUOTE:
-	if (*h == '\'') state = TAG;
-	break;
-      default:
-	assert(!"Cannot happen!");
-      }
-  }
-}
-#endif
-
 /* write_index_item -- write one item in the list of index terms */
 static void write_index_item(const void *term1, const VISIT which,
 			     const int depth)
@@ -463,61 +428,19 @@ static void write_index_item(const void *term1, const VISIT which,
     }
   }
 
-#if 0
-  int listmode = 0;
-
-  if (folding_cmp(globalprevious->sortkeys, globalprevious->nrkeys,
-		  term->sortkeys, term->nrkeys) == 0)
-    if (globalurlprevious) {
-      string d = strchr(globalurlprevious,'#');
-      if (d)
-        listmode = strncmp(globalurlprevious, term->url, d - globalurlprevious);
-      else
-        listmode = strcmp(globalurlprevious, term->url);
-    }
-#endif
-
   /* Print a link */
-  switch (term->importance) {
-    case 1:
-#if 0
-      printf("%s <a href=\"%s\" title=\"", listmode ? ";" : ",", term->url);
-      print_full_term(term);
-      printf("\">%s</a>", use_secno ? term->secno : "#");
-#else
-      printf(", ");
-      printf("<a href=\"");
-      print_escaped(term->url);
-      printf("\"");
-      if (use_secno) print_title(term);
-      printf(">");
-      if (!use_secno) putchar('#');
-      else if (term->secno) print_escaped(term->secno);
-      else  print_escaped(unknown_name);
-      printf("</a>");
-#endif
-      break;
-    case 2:
-#if 0
-      printf("%s <a href=\"%s\" title=\"", listmode ? ";" : ",", term->url);
-      print_full_term(term);
-      printf("\"><strong>%s</strong></a>", use_secno ? term->secno : "#");
-#else
-      printf(", ");
-      printf("<a href=\"");
-      print_escaped(term->url);
-      printf("\"");
-      if (use_secno) print_title(term);
-      printf("><strong>");
-      if (!use_secno) putchar('#');
-      else if (term->secno) print_escaped(term->secno);
-      else  print_escaped(unknown_name);
-      printf("</strong></a>");
-#endif
-      break;
-    default:
-      assert(! "Cannot happen\n");
-  }
+  printf(", ");
+  printf("<a href=\"");
+  print_escaped(term->url);
+  printf("\"");
+  if (use_secno) print_title(term);
+  if (term->importance == 2) printf("><strong>"); else printf(">");
+  if (use_sectitle)
+    printf("%s", term->sectitle ? term->sectitle : term->doctitle);
+  else if (!use_secno) putchar('#');
+  else if (term->secno) print_escaped(term->secno);
+  else print_escaped(unknown_name);
+  if (term->importance == 2) printf("</strong></a>"); else printf("</a>");
 
   /* Remember this term */
   globalprevious = term;
@@ -683,7 +606,8 @@ static void copy_contents(Tree t, string *s)
 
 /* copy_to_index -- copy the contents of element h to the index db */
 static void copy_to_index(Tree t, Indexterm *terms, int importance,
-			  conststring secno, conststring doctitle)
+			  conststring secno, conststring sectitle,
+			  conststring doctitle)
 {
   conststring id, title;
   string h;
@@ -705,6 +629,7 @@ static void copy_to_index(Tree t, Indexterm *terms, int importance,
       new(term);
       term->importance = importance;
       term->secno = secno ? newstring(secno) : NULL;
+      term->sectitle = sectitle ? newstring(sectitle) : NULL;
       term->doctitle = newstring(doctitle);
       term->url = NULL;
       strapp(&term->url, base, "#", id, NULL);
@@ -729,6 +654,7 @@ static void copy_to_index(Tree t, Indexterm *terms, int importance,
       new(term);
       term->importance = importance;
       term->secno = secno ? newstring(secno) : NULL;
+      term->sectitle = sectitle ? newstring(sectitle) : NULL;
       term->doctitle = newstring(doctitle);
       term->url = NULL;
       strapp(&term->url, base, "#", id, NULL);
@@ -750,7 +676,8 @@ static bool in_list(const string word, const string *list)
 }
 
 /* collect -- collect index terms, add IDs where needed */
-static void collect(Tree t, Indexterm *terms, string *secno, string *doctitle)
+static void collect(Tree t, Indexterm *terms, string *secno,
+		    string *sectitle, string *doctitle)
 {
   int importance;
   Tree h;
@@ -771,6 +698,12 @@ static void collect(Tree t, Indexterm *terms, string *secno, string *doctitle)
 	  dispose(*secno);
 	  *secno = newstring(unknown_name);
 	}
+	if (eq(h->name, "h1") || eq(h->name, "h2") || eq(h->name, "h3") ||
+	    eq(h->name, "h4") || eq(h->name, "h5") || eq(h->name, "h5")) {
+	  dispose(*sectitle);
+	  copy_contents(h, sectitle);
+	  trim(*sectitle);
+	}
 	if (eq(h->name, "dfn")) importance = 2;
 	else if (exclude_elts && in_list(h->name, exclude_elts)) importance = 0;
 	else if (only_elts && !in_list(h->name, only_elts)) importance = 0;
@@ -783,9 +716,9 @@ static void collect(Tree t, Indexterm *terms, string *secno, string *doctitle)
 	if (importance != 0) {
 	  /* Give it an ID, if it doesn't have one */
 	  if (! get_attrib(h, "id")) set_attrib(h, "id", gen_id(h));
-	  copy_to_index(h, terms, importance, *secno, *doctitle);
+	  copy_to_index(h, terms, importance, *secno, *sectitle, *doctitle);
 	} else {
-	  collect(h, terms, secno, doctitle);
+	  collect(h, terms, secno, sectitle, doctitle);
 	}
 	break;
       case Root: assert(! "Cannot happen"); break;
@@ -798,16 +731,15 @@ static void collect(Tree t, Indexterm *terms, string *secno, string *doctitle)
 static void load_index(const string indexdb, Indexterm *terms)
 {
   FILE *f;
-  int n1, n2, n3, n4, n5;
-  char line[MAXSTR];
+  int n1, n2, n3, n4, n5, n6;
+  char *line = NULL;
+  size_t linesize = 0;
   Indexterm term;
   string h;
 
   if (! (f = fopen(indexdb, "r"))) return;	/* Assume file not found... */
 
-  /* TODO: allow for arbitrarily long lines instead of MAXSTR */
-  while (fgets(line, sizeof(line), f)) {
-#if 1
+  while (getline(&line, &linesize, f) != -1) {
     n1 = strcspn(line, "\t");
     if (line[n1] != '\t') errx(1, "Illegal syntax in %s", indexdb);
     n2 = n1 + 1 + strcspn(line + n1 + 1, "\t");
@@ -816,8 +748,10 @@ static void load_index(const string indexdb, Indexterm *terms)
     if (line[n3] != '\t') errx(1, "Illegal syntax in %s", indexdb);
     n4 = n3 + 1 + strcspn(line + n3 + 1, "\t");
     if (line[n4] != '\t') errx(1, "Illegal syntax in %s", indexdb);
-    n5 = n4 + 1 + strcspn(line + n4 + 1, "\t\n");
-    if (line[n5] != '\n') errx(1, "Illegal syntax in %s", indexdb);
+    n5 = n4 + 1 + strcspn(line + n4 + 1, "\t");
+    if (line[n5] != '\t') errx(1, "Illegal syntax in %s", indexdb);
+    n6 = n5 + 1 + strcspn(line + n5 + 1, "\t\n");
+    if (line[n6] != '\n') errx(1, "Illegal syntax in %s", indexdb);
     new(term);
     h = newnstring(line, n1);
     switch (line[n1 + 1]) {
@@ -827,36 +761,15 @@ static void load_index(const string indexdb, Indexterm *terms)
     }
     term->url = newnstring(line + n2 + 1, n3 - n2 - 1);
     term->secno = newnstring(line + n3 + 1, n4 - n3 - 1);
-    term->doctitle = newnstring(line + n4 + 1, n5 - n4 - 1);
+    term->sectitle = newnstring(line + n4 + 1, n5 - n4 - 1);
+    term->doctitle = newnstring(line + n5 + 1, n6 - n5 - 1);
     parse_subterms(term, h);
     if (! tsearch(term, (void**)terms, termcmp))
       errx(1, "Out of memory while loading %s", indexdb);
-#else
-    chomp(line);
-    n = strcspn(line, "\t");
-    if (line[n] != '\t') errx(1, "Illegal syntax in %s", indexdb);
-    new(term);
-    h = newnstring(line, n);
-    switch (line[n + 1]) {
-      case '1': term->importance = 1; break;
-      case '2': term->importance = 2; break;
-    default: errx(1, "Error in %s (column 2 must be '1' or '2')", indexdb);
-    }
-    if (line[n+2] != '\t') errx(1, "Illegal syntax in %s", indexdb);
-    n3 = n + 3 + strcspn(line + n + 3, "\t");
-    if (line[n3] != '\t') errx(1, "Illegal syntax in %s", indexdb);
-    n4 = n3 + 1 + strcspn(line + n3 + 1, "\t");
-    if (line[n4] != '\t') errx(1, "Illegal syntax in %s", indexdb);
-    term->url = newnstring(line + n + 3, n3 - n - 3);
-    term->secno = newnstring(line + n3 + 1, n4 - n3 - 1);
-    term->doctitle = newstring(line + n4 + 1);
-    parse_subterms(term, h);
-    if (! tsearch(term, (void**)terms, termcmp))
-      errx(1, "Out of memory while loading %s", indexdb);
-#endif
   }
 
   fclose(f);
+  free(line);
 }
 
 /* save_a_term -- write one term to globalfile */
@@ -870,8 +783,9 @@ static void save_a_term(const void *term1, const VISIT which, const int dp)
       if (i > 0) fprintf(globalfile, "!!");
       fprintf(globalfile, "%s", term->terms[i]);
     }
-    fprintf(globalfile, "\t%d\t%s\t%s\t%s\n", term->importance, term->url,
+    fprintf(globalfile, "\t%d\t%s\t%s\t%s\t%s\n", term->importance, term->url,
 	    term->secno ? term->secno : (use_secno ? unknown_name : "#"),
+	    term->sectitle ? term->sectitle : term->doctitle,
 	    term->doctitle);
   }
 }
@@ -914,7 +828,7 @@ int main(int argc, char *argv[])
 {
   bool write = true;
   Indexterm termtree = NULL;	/* Sorted tree of terms */
-  string secno, doctitle;
+  string secno, doctitle, sectitle;
   int c, status = 200;
 
   /* Bind the parser callback routines to our handlers */
@@ -931,14 +845,15 @@ int main(int argc, char *argv[])
 
   yyin = NULL;
 
-  while ((c = getopt(argc, argv, "txb:i:cnfrs:u:O:X:")) != -1)
+  while ((c = getopt(argc, argv, "txb:i:cnNfrs:u:O:X:")) != -1)
   switch (c) {
   case 't': bctarget = false; break; /* Don't write <a name> after each ID */
   case 'x': xml = true; break;	/* Output as XML */
   case 'b': base = newstring(optarg); break; /* Set base of URL */
   case 'i': indexdb = newstring(optarg); break;	/* Set name of index db */
   case 'c': userclassnames = tokenize(optarg); break; /* Set class names */
-  case 'n': use_secno = true; break; /* Print section numbers instead of "#" */
+  case 'n': use_secno = true; use_sectitle = false; break;
+  case 'N': use_sectitle = true; use_secno = false; break;
   case 'f': final = true; break; /* "Final": remove used attributes */
   case 'r': trim_punct = false; break; /* Do not remove trailing punctuation */
   case 's': section_name = newstring(optarg); break;
@@ -970,8 +885,9 @@ int main(int argc, char *argv[])
 
   /* Scan for index terms, add them to the tree, add IDs where needed */
   secno = NULL;
+  sectitle = NULL;
   doctitle = newstring("");
-  collect(get_root(tree), &termtree, &secno, &doctitle);
+  collect(get_root(tree), &termtree, &secno, &sectitle, &doctitle);
 
   /* Write out the document, adding <A NAME> and replacing <!--index--> */
   expand(get_root(tree), &write, termtree);
@@ -980,8 +896,5 @@ int main(int argc, char *argv[])
   if (indexdb) save_index(indexdb, termtree);
 
   fclose(yyin);
-#if 0
-  tree_delete(tree);				/* Just to test memory mgmt */
-#endif
   return 0;
 }
