@@ -1,15 +1,12 @@
 /*
  * List all links from the given document.
  *
- * Copyright  1994-2000 World Wide Web Consortium
+ * Copyright © 1994-2000 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
- * TODO: An option to output URIs mapped to ASCII via Punycode and
- * %-escaping instead of IRIs (in UTF-8).
- *
  * Bert Bos <bert@w3.org>
  * Created 31 July 1999
- * $Id: hxwls.c,v 1.10 2016/04/12 23:21:30 bbos Exp $
+ * $Id: hxwls.c,v 1.12 2017/12/07 02:05:23 bbos Exp $
  */
 #include "config.h"
 #include <assert.h>
@@ -233,9 +230,11 @@ void handle_starttag(void *clientdata, string name, pairlist attribs)
     output("img", NULL, pairlist_get(attribs, "src"));
     output("longdesc", NULL, pairlist_get(attribs, "longdesc"));
   } else if (strcasecmp(name, "input") == 0) {
-    output("input", NULL, pairlist_get(attribs, "href"));
+    output("input", NULL, pairlist_get(attribs, "src"));
   } else if (strcasecmp(name, "object") == 0) {
     output("object", NULL,  pairlist_get(attribs, "data"));
+    output("object", NULL,  pairlist_get(attribs, "classid"));
+    output("object", NULL,  pairlist_get(attribs, "codebase"));
   } else if (strcasecmp(name, "area") == 0) {
     output("area", pairlist_get(attribs, "rel"), pairlist_get(attribs, "href"));
   } else if (strcasecmp(name, "ins") == 0) {
@@ -258,6 +257,13 @@ void handle_starttag(void *clientdata, string name, pairlist attribs)
     output("script", NULL, pairlist_get(attribs, "src"));
   } else if (strcasecmp(name, "body") == 0) {
     output("body", NULL, pairlist_get(attribs, "background"));
+  } else if (strcasecmp(name, "video") == 0) {
+    output("video", NULL, pairlist_get(attribs, "src"));
+  } else if (strcasecmp(name, "audio") == 0) {
+    output("audio", NULL, pairlist_get(attribs, "src"));
+  } else if (strcasecmp(name, "source") == 0) {
+    output("source", NULL, pairlist_get(attribs, "srcset"));
+    output("source", NULL, pairlist_get(attribs, "src"));
   }
 
   /* Free memory */
