@@ -1,6 +1,6 @@
 :
 trap 'rm -rf $TMP' 0
-TMP=`mktemp -d` || exit 1
+TMP=`mktemp -d /tmp/tmp.XXXXXXXXXX` || exit 1
 EXEDIR=$PWD
 
 cd -P $TMP || exit 1		# -P to avoid symlinks
