@@ -18,7 +18,7 @@ while [ $(( ( i += 1 ) <= 10 )) -ne 0 ]; do
   p=$(($PORT + $i))
   q=$(($p + 1))
   printf "HTTP/1.1 302\r\nLocation: http://127.0.0.1:$q/\r\n\r" |\
-    (nc -N -l -n -p $p || nc -l -n $p) >/dev/null 2>&1 &
+    (nc -q0 -l -n -p $p || nc -l -n $p) &
 done
 
 sleep 1				# Give the servers time to start
