@@ -28,9 +28,9 @@ cat >$TMP3 <<EOF
 </p><h3><span class="secno">1.1.1. </span>Heading 3</h3><p><dfn id="z-term">Z-term</dfn>
 </p><h1><span class="secno">2. </span>Index</h1><!--begin-index-->
 <ul class="indexlist">
-<li>&lt;M-term&gt;, <a href="#ltm-termgt" title="&lt;M-term&gt;"><strong>1.1.</strong></a>
-<li>A-term, <a href="#a-term" title="A-term"><strong>#</strong></a>
-<li>Z-term, <a href="#z-term" title="Z-term"><strong>1.1.1.</strong></a>
+<li>&lt;M-term&gt;, <a href="#ltm-termgt" title="section 1.1."><strong>1.1.</strong></a>
+<li>A-term, <a href="#a-term" title="section ??"><strong>??</strong></a>
+<li>Z-term, <a href="#z-term" title="section 1.1.1."><strong>1.1.1.</strong></a>
 </ul><!--end-index--></body></html>
 EOF
 
