@@ -29,9 +29,9 @@ cat >$TMP3 <<EOF
 </p><h1><span class="secno">2. </span>Index</h1><ul class="indexlist">
 <li>term
   <ul>
-  <li>A, <a href="#a-term" title="term, A"><strong>#</strong></a>
-  <li>M, <a href="#ltm-termgt" title="term, M"><strong>1.1.</strong></a>
-  <li>Z, <a href="#z-term" title="term, Z"><strong>1.1.1.</strong></a>
+  <li>A, <a href="#a-term" title="section ??"><strong>??</strong></a>
+  <li>M, <a href="#ltm-termgt" title="section 1.1."><strong>1.1.</strong></a>
+  <li>Z, <a href="#z-term" title="section 1.1.1."><strong>1.1.1.</strong></a>
 </ul>
 </ul></body></html>
 EOF
