@@ -9,12 +9,18 @@ cat >$TMP1 <<-EOF
 	<a href="foo.html">.</a>
 	<img src="bar/foo.png">
 	<img src="../bar/foo.png">
+	<picture>
+	  <source type="image/svg+xml" srcset="foo.svg">
+	  <img src="foo.png" alt="">
+	</picture>
 EOF
 cat >$TMP2 <<-EOF
 	http://example.org/style.css
 	../othersub/foo.html
 	../othersub/bar/foo.png
 	../bar/foo.png
+	../othersub/foo.svg
+	../othersub/foo.png
 EOF
 ./hxwls -b ../othersub/base $TMP1 >$TMP3
 cmp -s $TMP2 $TMP3
