@@ -1,14 +1,14 @@
 /*
  * Routines to wrap lines and indent them.
  *
- * Copyright  1994-2000 World Wide Web Consortium
+ * Copyright © 1998-2016 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * To do: count characters, not bytes
  *
  * Bert Bos
  * Created 10 May 1998
- * $Id: textwrap.c,v 1.29 2016/10/17 17:43:17 bbos Exp $
+ * $Id: textwrap.c,v 1.32 2017/11/24 10:14:49 bbos Exp $
  */
 #include "config.h"
 #include <stdio.h>
@@ -60,7 +60,7 @@ EXPORT void flush()
     for (i = -1, j = 0, k = 0; j < len && (k < maxlinelen || i == -1); j++)
       if (buf[j] == ' ') {i = j; k++;}
       else if (buf[j] == BREAKOP) i = j; /* Breakpoint but no character */
-      else if ((buf[j] & 0x80) == 0 || (buf[j] & 0xC0) == 0xC0) k++; /* Char */
+      else if ((buf[j] & 0xC0) != 0x80) k++; /* Start of a UTF-8 sequence */
     if (i < 0) break;				/* No breakpoint */
     assert(i >= 0);				/* Found a breakpoint at i */
     assert(buf[i] == ' ' || buf[i]==BREAKOP);
@@ -68,7 +68,7 @@ EXPORT void flush()
     for (j = 0; j < i; j++)
       if (buf[j] != BREAKOP) {
 	putchar(buf[j] == NBSP ? ' ' : buf[j]);
-	if ((buf[j] & 0x80) == 0 || (buf[j] & 0xC0) == 0xC0) bufchars--;
+	if ((buf[j] & 0xC0) != 0x80) bufchars--;
       }
     putchar('\n');				/* Break line */
     linelen = 0;
@@ -91,8 +91,7 @@ EXPORT void flush()
     if (buf[j] == BREAKOP) /* skip */;
     else if (buf[j] == '\n' || buf[j] == '\r') {putchar(buf[j]); linelen = 0;}
     else if (buf[j] == NBSP) {putchar(' '); linelen++;}
-    else if ((buf[j] & 0x80) == 0) {putchar(buf[j]); linelen++;}
-    else if ((buf[j] & 0xC0) == 0xC0) {putchar(buf[j]); linelen++;}
+    else if ((buf[j] & 0xC0) != 0x80) {putchar(buf[j]); linelen++;}
     else putchar(buf[j]);
   bufchars = 0;
   len = 0;
@@ -115,7 +114,7 @@ EXPORT void outc(char c, bool preformatted)
     while (len < level * indent) {buf[len++] = NBSP; bufchars++;}
   if (c == ' ' && len && buf[len-1] == ' ') return; /* Skip multiple spaces */
   while (len >= buflen) {buflen += 1024; renewarray(buf, buflen);}
-    if ((c & 0x80) == 0 || (c & 0xC0) == 0xC0) bufchars++; /* Character */
+    if ((c & 0xC0) != 0x80) bufchars++; /* Character */
   buf[len++] = c;				/* Finally, insert c */
   prev = c;					/* Remember for next round */
 }
